<?php
/*
Plugin Name: WP Google Weather
Plugin URI: http://imwill.com/wp-google-weather/
Description: Displays a weather widget using the Google weather API.
Version: 0.5
Author: Hendrik Will
Author URI: http://imwill.com
*/

require_once(ABSPATH . WPINC . '/formatting.php');

#defining default variables
static $hw_wpgw_city = 'Braunschweig,Germany';
static $hw_wpgw_lang = 'en';
static $hw_wpgw_forecast = TRUE;

/**
 * Add function to widgets_init that'll load our widget.
 * @since 0.1
 */
add_action( 'widgets_init', 'load_hw_wpgw' );

/**
 * Register our widget.
 * 'hw_wpgw' is the widget class used below.
 *
 * @since 0.1
 */
function load_hw_wpgw() {
	register_widget( 'hw_wpgw' );
}

/**
 * WP Google Weather Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update. Awesome!
 *
 * @since 0.1
 */
class hw_wpgw extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function hw_wpgw() {
		#Widget settings
		$widget_ops = array( 'description' => __('A widget that displays the weather.', 'hw_wpgw') );

		#Widget control settings
		$control_ops = array( 'width' => 200, 'height' => 350, 'id_base' => 'hw_wpgw' );

		#Create the widget
		$this->WP_Widget( 'hw_wpgw', __('WP Google Weather', 'hw_wpgw'), $widget_ops, $control_ops );
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['city'] = strip_tags( $new_instance['city'] );
		$instance['lang'] = strip_tags( $new_instance['lang'] );
		$instance['temp'] = $new_instance['temp']['select_value'];
		$instance['forecast'] = $new_instance['forecast'];
		$instance['alignment'] = $new_instance['alignment'];
		
		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		#Set up some default widget settings
		$defaults = array( 'title' => __('Example', 'example'), 'city' => __('Braunschweig, Germany', 'city'), 'lang' => 'en', 'temp' => 'f', 'forecast' => true, 'alignment' => false );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'hybrid'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" size="30" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'city' ); ?>"><?php _e('WOEID <i>get from Yahoo Weather site</i>:', 'city'); ?></label>
			<input id="<?php echo $this->get_field_id( 'city' ); ?>" name="<?php echo $this->get_field_name( 'city' ); ?>" value="<?php echo $instance['city']; ?>" size="30" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'temp' ); ?>"><?php _e('Temperature:', 'temp'); ?></label>
			<select id="<?php echo $this->get_field_id( 'temp' ); ?>" name="<?php echo $this->get_field_name( 'temp' ); ?>[select_value]">
      			<option value="c" <?php if ($instance['temp'] == 'c') echo 'selected'; ?>>Celsius</option>
      			<option value="f" <?php if ($instance['temp'] == 'f') echo 'selected'; ?>>Fahrenheit</option>
    		</select>			
		</p>
<!--
		<p>
			<label for="<?php echo $this->get_field_id( 'lang' ); ?>"><?php _e('Language:', 'lang'); ?></label>
			<input id="<?php echo $this->get_field_id( 'lang' ); ?>" name="<?php echo $this->get_field_name( 'lang' ); ?>" value="<?php echo $instance['lang']; ?>" size="2" />
		</p>


		<p>
			<input class="checkbox" type="checkbox" <?php if($instance['forecast'] == true) echo 'checked'; ?> id="<?php echo $this->get_field_id( 'forecast' ); ?>" name="<?php echo $this->get_field_name( 'forecast' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'forecast' ); ?>"><?php _e('Display forecast?', 'forecast'); ?></label>
		</p>
-->
		<p>
			<input class="checkbox" type="checkbox" <?php if($instance['alignment'] == true) echo 'checked'; ?> id="<?php echo $this->get_field_id( 'alignment' ); ?>" name="<?php echo $this->get_field_name( 'alignment' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'alignment' ); ?>"><?php _e('Alignment centered?', 'alignment'); ?></label>
		</p>
	
		
	<?php
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		#Our variables from the widget settings
		$title = apply_filters('widget_title', $instance['title'] );
		$city = $instance['city'];
		$temp = $instance['temp'];
		$lang = $instance['lang'];
		$forecast = $instance['forecast'];
		$alignment = $instance['alignment'];

		#Before widget (defined by themes)
		echo $before_widget;

		#Display the widget title if one was input (before and after defined by themes)
		if ( $title )
			echo $before_title . $title . $after_title;

		#Display name from widget settings if one was input		
		$this->buildWidget($city, $temp, $lang, $forecast, $alignment);
			
		#After widget (defined by themes)
		echo $after_widget;
	}
	function getData($city,$temp) {
	$result = file_get_contents('http://weather.yahooapis.com/forecastrss?w='.$city.'&u='.$temp.'');

		$xml = simplexml_load_string($result);


		$xml->registerXPathNamespace('yweather', 'http://xml.weather.yahoo.com/ns/rss/1.0');
		$location = $xml->channel->xpath('yweather:location');

		if(!empty($location)){
			foreach($xml->channel->item as $item){
				$current = $item->xpath('yweather:condition');
				$forecast = $item->xpath('yweather:forecast');
				$current = $current[0];
 
				$index = $current['code'];
				$idxDay0 = (string)$forecast[0]['day'];
				$idxDay0 = (string)$dayPL[$idxDay0];		
				$forecast[0]['day'] = $idxDay0;

				$idxDay1 = (string)$forecast[1]['day'];
				$idxDay1 = (string)$dayPL[$idxDay1];		
				$forecast[1]['day'] = $idxDay1;
					
					

			}
		}else{
			$output = '<h1>No results found, please try a different zip code.</h1>';
		}
	

		return $current;
		
	}
	
	function buildWidget($city, $temp, $lang, $forecast, $alignment) {
		$current = $this->getData($city, $temp);	
		
		if($alignment == true) {
			$alignmentclass = 'centered';
		}
		if ($temp == "c"){
			$temp_scale = "&deg;C";
		}
		else{
			$temp_scale = "&deg;F";
		}
		echo '<div class="hw_wpgw">
		<dl class="'.$alignmentclass.'">
			<dd class="today">
				<span class="condition">'.$current['text'].'</span>
				
				<span class="temperature">'.$current['temp'].''.$temp_scale.'</span>
				<img src="http://l.yimg.com/a/i/us/we/52/'.$current['code'].'.gif" alt="'.$current['text'].'" />
			</dd>
		';	
		
		if($forecast == true) {
			echo '
				<dd class="day1">
					<span class="day">'.$conditions['forecast'][1]['day'].'</span>
					<img src="http://www.google.com'.$conditions['forecast'][1]['icon'].'" alt="'.$conditions['forecast'][1]['condition'].'" title="'.$conditions['forecast'][1]['condition'].'" /><br />
					<span class="temperature">'.$conditions['forecast'][1]['high'].'/'.$conditions['forecast'][1]['low'].'</span><br /> 
				</dd>
				<dd class="day2">
					<span class="day">'.$conditions['forecast'][2]['day'].'</span>
					<img src="http://www.google.com'.$conditions['forecast'][2]['icon'].'" alt="'.$conditions['forecast'][2]['condition'].'" title="'.$conditions['forecast'][2]['condition'].'" /><br />
					<span class="temperature">'.$conditions['forecast'][2]['high'].'/'.$conditions['forecast'][2]['low'].'</span><br /> 
				</dd>
				<dd class="day3">
					<span class="day">'.$conditions['forecast'][3]['day'].'</span>
					<img src="http://www.google.com'.$conditions['forecast'][3]['icon'].'" alt="'.$conditions['forecast'][3]['condition'].'" title="'.$conditions['forecast'][3]['condition'].'" /><br />
					<span class="temperature">'.$conditions['forecast'][3]['high'].'/'.$conditions['forecast'][3]['low'].'</span><br /> 
				</dd>
				
				';	
			}
		echo '
		</dl>
		</div>
		<br/><a href="http://echiny.pl/turystyka/aktualna-pogoda-w-chinach/">Więcej miast</a>
		<div style="clear: both;"></div>		
		';
	}
	
	function replaceChars($data){
		$search = array('Ä', 'Ö', 'Ü', 'ä', 'ö', 'ü', ' ');
		$replace = array('Ae', 'Oe', 'Ue', 'ae', 'oe', 'ue', '%20');
		$output = str_replace($search, $replace, $data);
		
		return $output;
	}
}

function wpgw_css() {
	echo '<link rel="stylesheet" type="text/css" media="screen" href="'. WP_PLUGIN_URL . '/wp-google-weather/wp-google-weather.css"/>';	
}

add_action('wp_head', 'wpgw_css');

/**
 * Add function to load weather shortcode.
 * @since 0.4
 */

add_shortcode('wp_google_weather', 'hw_wp_gw_shortcode');

function hw_wp_gw_shortcode($atts, $content = null) {
	extract(shortcode_atts(array(
		"city" => 'Braunschweig, Germany',
		"temperature" => 'c',
		"language" => 'en',
		"forecast" => 'true'
		), $atts)
	);
	$hw_wpgw = new hw_wpgw();
	ob_start();
	$hw_wpgw->buildWidget($city, $temperature, $language, $forecast, $alignment);
	$output = ob_get_contents();
	ob_end_clean();
	return $output;
}

?>